<!-- start-no-pypi -->
[![codecov](https://codecov.io/gh/labd/wagtail-site-inheritance/branch/master/graph/badge.svg)](https://codecov.io/gh/labd/wagtail-site-inheritance)
[![pypi](https://img.shields.io/pypi/v/wagtail-site-inheritance.svg)](https://pypi.python.org/pypi/wagtail-site-inheritance/)
[![readthedocs](https://readthedocs.org/projects/wagtail-site-inheritance/badge/)](https://wagtail-site-inheritance.readthedocs.io/en/latest/)
[![tests](https://github.com/labd/wagtail-site-inheritance/workflows/Python%20Tests/badge.svg)](https://github.com/labd/wagtail-site-inheritance/actions)
<!-- end-no-pypi -->

# Wagtail Site Inheritance

## Installation

```shell
pip install wagtail-site-inheritance
```


## TODO
 - [ ] https://github.com/wagtail/wagtail/issues/4925
